==> Video_Audio_Image_Downloader-0.0.9-py3-none-any.whl: source/lib/help.py <==
class help:
        
        
    def Youtube_Download_video_Resolution_help(self):
        print(f"Usage: <downloder> youtube video -get_resolution [Options]")
        print()
        print("Description :: ")
        print("In this command is used to show's Resolution of Youtube Video")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("   -get_resolution       Show's the Resolution of the Youtube")
        print()
        print("Optional arguments : ")
        print("-h, --help   show this help message and exit")
        
        
    def Youtube_Download_video_help(self):
        print(f"Usage: <downloder> youtube video [Options]...")
        print()
        print("Description :: ")
        print("In this command is used to Download Youtube Video's with Specified Path with Specifed Resolution")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("   -source       Source of our Youtube Video")
        print("   -resolution   Resolution of our Youtube Video")
        print("   -path         which path the file to be saved")
        print()
        print("Optional arguments : ")
        print("-h, --help   show this help message and exit")
        
    def Youtube_Download_Audio_help(self):
        print("Usage: <downloder> youtube audio [Options]...")
        print()
        print("Description :: ")
        print("In this command is used to Download Youtube Audio's with Specified Path with Specifed Resolution")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("   -source       Source of our Youtube Audio")
        print("   -filename     Name of the Audio File")
        print("   -path         which path the file to be saved")
        print()
        print("Optional arguments : ")
        print("   -h, --help   show this help message and exit")

    def Image_Download_help(self):
        print("Usage: <downloder> Image [Options]...")
        print()
        print("Description :: ")
        print("In this command is used to Download Image's with Specified Path with Filename")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("   -source       Source of our Image to be download")
        print("   -filename     Name of the Image File")
        print("   -path         which path the file to be saved")
        print()
        print("Optional arguments : ")
        print()
        print("   -h, --help   show this help message and exit")

==> Video_Audio_Image_Downloader-0.1.0-py3-none-any.whl: source/lib/help.py <==
class help:
        
        
    def Youtube_Download_video_Resolution_help(self):
        print(f"Usage: <downloder> youtube video -get_resolution [Options]")
        print()
        print("Description :: ")
        print("In this command is used to show's Resolution of Youtube Video")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("   -get_resolution       Show's the Resolution of the Youtube")
        print()
        print("Optional arguments : ")
        print("-h, --help   show this help message and exit")
        
        
    def Youtube_Download_video_help(self):
        
        print(f"Usage: <Downloader> Youtube Video [Options]...")
        print()
        print("Description :: ")
        print("             In this command is used to Download Youtube Video's with Specified Path with Specifed Resolution")
        print()
        print("Options  are :")
        print()
        print("positional arguments :: ")
        print("         -source             Source of our Youtube Video")
        print()
        print("Optional arguments :: ")
        print("         -resolution         Resolution of our Youtube Video")
        print("         -path               which path the file to be saved")
        print("-h,      --help              show this help message and exit")
        
    def Youtube_Download_Audio_help(self):
        print("Usage: <downloder> youtube audio [Options]...")
        print()
        print("Description :: ")
        print("In this command is used to Download Youtube Audio's with Specified Path with Specifed Resolution")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("         -source       Source of our Youtube Audio")
        print("         -filename     Name of the Audio File")
        print("         -path         which path the file to be saved")
        print()
        print("Optional arguments : ")
        print("   -h, --help   show this help message and exit")

    def Image_Download_help(self):
        print("Usage: <downloder> Image [Options]...")
        print()
        print("Description :: ")
        print("In this command is used to Download Image's with Specified Path with Filename")
        print()
        print("Options  are :")
        print()
        print("positional arguments : ")
        print("   -source       Source of our Image to be download")
        print("   -filename     Name of the Image File")
        print("   -path         which path the file to be saved")
        print()
        print("Optional arguments : ")
        print()
        print("   -h, --help   show this help message and exit")
